@@ -30,7 +30,15 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
                                          QIcon(":/images/button-filter.png")));
     this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::ApplicationModal);
-    this->setMinimumSize(520, 400);
+    this->setMinimumSize(520, 440);
+
+    QSettings settings;
+    QSize savedWindowsize = settings.value("FilterEditor/filterWindowSize")
+                                    .toSize();
+    if (savedWindowsize.isValid())
+    {
+        this->resize(savedWindowsize);
+    }
 
 
     ruleString = tr("%1 if %2 contains: %3",
@@ -131,6 +139,7 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
             this, SLOT(hide()));
     this->addAction(closeAction);
 
+
     // Layout
     topLayout = new QHBoxLayout();
     topLayout->addWidget(actionTypeComboBox);
@@ -163,11 +172,11 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
 
     mainLayout = new QVBoxLayout();
     mainLayout->addWidget(explanationLabel);
-    mainLayout->addSpacing(8);
+    mainLayout->addSpacing(4);
     mainLayout->addWidget(newFilterGroupBox);
-    mainLayout->addSpacing(8);
+    mainLayout->addSpacing(2);
     mainLayout->addWidget(currentFiltersGroupBox);
-    mainLayout->addSpacing(16);
+    mainLayout->addSpacing(8);
     mainLayout->addLayout(bottomLayout);
     this->setLayout(mainLayout);
 
@@ -203,7 +212,11 @@ void FilterEditor::loadFilters()
         QListWidgetItem *item = new QListWidgetItem(ruleString
                                                     .arg(actionTypeComboBox->itemText(actionType))
                                                     .arg("'" + filterTypeComboBox->itemText(filterType) + "'")
-                                                    .arg("  " + filterWords));
+                                                    .arg("'" + filterWords + "'"));
+        // Note: Don't mess with spaces around the ruleString parameters,
+        // since the structure is different in other languages
+
+
         item->setData(Qt::UserRole, itemMap);
 
         this->currentFiltersListWidget->addItem(item);
@@ -250,7 +263,8 @@ void FilterEditor::addFilter()
     QListWidgetItem *item = new QListWidgetItem(ruleString
                                                 .arg(actionTypeComboBox->currentText())
                                                 .arg("'" + filterTypeComboBox->currentText() + "'")
-                                                .arg("  " + words));
+                                                .arg("'" + words + "'"));
+    // Just as in loadFilters(), don't mess with spaces around the parameters
     item->setData(Qt::UserRole, itemMap);
 
     currentFiltersListWidget->addItem(item);
@@ -297,3 +311,25 @@ void FilterEditor::saveFilters()
     this->hide();
 }
 
+
+
+//////////////////////////////////////////////////////////////////////////////
+/////////////////////////////// PROTECTED ////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
+
+
+void FilterEditor::closeEvent(QCloseEvent *event)
+{
+    this->hide();
+    event->ignore();
+}
+
+
+void FilterEditor::hideEvent(QHideEvent *event)
+{
+    QSettings settings;
+    settings.setValue("FilterEditor/filterWindowSize", this->size());
+
+    event->accept();
+}
