@@ -112,6 +112,9 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     newAvatarInfoLabel->setWordWrap(true);
     newAvatarInfoLabel->setAlignment(Qt::AlignCenter);
     newAvatarInfoLabel->setFrameStyle(QFrame::Box | QFrame::Raised);
+    newAvatarInfoLabel->setAutoFillBackground(true);
+    newAvatarInfoLabel->setForegroundRole(QPalette::HighlightedText);
+    newAvatarInfoLabel->setBackgroundRole(QPalette::Highlight);
     newAvatarInfoLabel->hide();
 
 
