@@ -57,8 +57,8 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     demoObjectData.insert("objectType",     "note");
     demoObjectData.insert("id",             "demo-post-id");
 
-    // Show date/time when Dianara v1.3.4 was released
-    demoObjectData.insert("published",      "2016-06-11T19:00:00Z");
+    // Show date/time when latest stable version was released
+    demoObjectData.insert("published",      "2016-10-09T19:00:00Z");
 
 
     QSettings settings; // FIXME: kinda tmp, until posts have "unread" status, etc.
@@ -231,9 +231,8 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     currentPageButton = new QPushButton(QIcon::fromTheme("go-next-view-page"),
                                         "1 / 1",  // Correct value will be set on real update
                                         this);
-    // currentPageButton->setFlat(true); // Not flat, for now, to make it discoverable
     currentPageButton->setSizePolicy(QSizePolicy::MinimumExpanding,
-                                     QSizePolicy::Preferred);
+                                     QSizePolicy::Maximum);
     connect(currentPageButton, SIGNAL(clicked()),
             this, SLOT(showPageSelector()));
 
@@ -356,6 +355,14 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
             nextPageButton, SLOT(click()));
     this->addAction(nextPageAction);
 
+    // It's safer to use these QActions than setting shortcuts to buttons
+    // The latter gets messed up when built with Qt 5 and run under Plasma 5.x
+    showPageSelectorAction = new QAction(this);
+    showPageSelectorAction->setShortcut(QKeySequence("Ctrl+G"));
+    connect(showPageSelectorAction, SIGNAL(triggered()),
+            currentPageButton, SLOT(click()));
+    this->addAction(showPageSelectorAction);
+
 
     // Add the default "demo" post
     if (timelineType != PumpController::UserTimelineRequest)
@@ -427,6 +434,9 @@ TimeLine::~TimeLine()
                           this->fullTimelinePostCount);
         break;
 
+    case PumpController::UserTimelineRequest:
+        break;
+
     default:
         qDebug() << "Timeline destructor: timelineType is invalid!";
     }
@@ -494,7 +504,6 @@ void TimeLine::removeOldPosts(int minimumToKeep)
     }
 
     int postCounter = 0;
-    int deletedCounter = 0; // tmp, TESTS (EXTRALOGGING)
     foreach (Post *post, postsInTimeline)
     {
         if (postCounter >= maxPosts)
@@ -504,8 +513,8 @@ void TimeLine::removeOldPosts(int minimumToKeep)
             {
                 this->postsLayout->removeWidget(post);
                 this->postsInTimeline.removeOne(post);
+                this->objectsIdList.removeAt(postCounter);
                 delete post;
-                ++deletedCounter; // tmp, TESTS (EXTRALOGGING)
             }
         }
 
@@ -518,18 +527,6 @@ void TimeLine::removeOldPosts(int minimumToKeep)
 
     this->nextPageLink = this->pController->getFeedApiUrl(this->timelineType)
                        + "?before=" + lastPostId;
-
-#ifdef EXTRALOGGING
-    // tmp, TESTS - debugging via log
-    this->globalObj->logMessage(QString("##### %1 POSTS IN '%2' AFTER REMOVAL;  "
-                                        "%3 CAME IN, %4 WERE DELETED - "
-                                        "NEXT PAGE: %5")
-                                .arg(postsInTimeline.count())
-                                .arg(PumpController::getFeedNameAndPath(this->timelineType).first())
-                                .arg(minimumToKeep)
-                                .arg(deletedCounter)
-                                .arg(this->nextPageLink));
-#endif
 }
 
 
@@ -589,8 +586,6 @@ void TimeLine::updateCurrentPageNumber()
     this->currentPageButton->setText(QString("%1 / %2")
                                      .arg(currentPageString)
                                      .arg(totalPagesString));
-    // The shortcut needs to be set each time the text is changed
-    currentPageButton->setShortcut(QKeySequence("Ctrl+G"));
 
     this->currentPageButton->setToolTip(tr("Page %1 of %2.")
                                         .arg(currentPageString)
@@ -662,8 +657,6 @@ void TimeLine::resizePosts(QList<Post *> postsToResize, bool resizeAll)
 
     foreach (Post *post, postsToResize)
     {
-        post->resetResizesCount();
-
         // Call setPostContents() and setPostHeight()
 
         // New method, disabled for 1.3.1; has some drawbacks
@@ -763,6 +756,14 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
                                    QString nextLink, int totalItems)
 {
     qDebug() << "TimeLine::setTimeLineContents()";
+    if (this->commentingOnAnyPost())
+    {
+        // Extra protection, see https://gitlab.com/dianara/dianara-dev/issues/35
+        qDebug() << "Aborting timeline update due to comment in progress";
+        this->notifyBlockedUpdates();
+        return;
+    }
+
     int postListSize = postList.size();
 
     // Disable to avoid clicks to posts (which would mark them as read)
@@ -814,7 +815,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
             // The difference in pending posts is in the older pages, so doesn't count
             this->pendingToReceiveNextTime = 0;
 
-            // FIXME 1.3.5: On first load, should display the "pending" number
+            // FIXME 1.3.6: On first load, should display the "pending" number
             // at the bottom or at the "older" button
         }
         else
@@ -855,7 +856,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
     int insertedPosts = 0;
     bool needToInsertSeparator = false;
 
-    // Here we'll store the postID for the first (newest) post in the timeline
+    // Here we'll store the post ID for the first (newest) post in the timeline
     QString newestPostId; // (actually activity ID)
     // With it, we can know how many new posts (if any) we receive next time
 
@@ -896,7 +897,8 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
             // See if we have to filter it out (or highlight it)
             int filtered = this->fChecker->validateActivity(activity);
 
-            // See if we hide the post if it's already visible in the timeline
+
+            // See if we hide the post if a copy is already visible in the timeline
             bool postIsDuplicated = false;
             if (globalObj->getHideDuplicates()) // Depending on the setting
             {
@@ -1008,7 +1010,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
             }
 
 
-            this->objectsIdList.append(newPost->getObjectId());
+            this->objectsIdList.insert(insertedPosts, newPost->getObjectId());
             postsInsertedThisTime.append(newPost);
             this->postsLayout->insertWidget(insertedPosts, newPost);
             this->postsInTimeline.insert(insertedPosts, newPost);
@@ -1179,7 +1181,7 @@ void TimeLine::addLikesFromMinorFeed(QString objectId, QString objectType,
                                      QString actorId, QString actorName,
                                      QString actorUrl)
 {
-    // FIXME 1.3.5: handle updating likes in comments
+    // FIXME 1.3.6: handle updating likes in comments
     foreach (Post *post, postsInTimeline)
     {
         if (post->getObjectId() == objectId)
@@ -1192,7 +1194,7 @@ void TimeLine::addLikesFromMinorFeed(QString objectId, QString objectType,
 void TimeLine::removeLikesFromMinorFeed(QString objectId, QString objectType,
                                         QString actorId)
 {
-    // FIXME 1.3.5: handle updating likes in comments
+    // FIXME 1.3.6: handle updating likes in comments
     foreach (Post *post, postsInTimeline)
     {
         if (post->getObjectId() == objectId)
@@ -1291,7 +1293,7 @@ void TimeLine::setCommentsInPost(QVariantList commentsList,
     qDebug() << "Looking for the originating Post() object";
     foreach (Post *post, postsInTimeline)
     {
-        if (post->commentsURL() == originatingPostCleanUrl)
+        if (post->commentsUrl() == originatingPostCleanUrl)
         {
             qDebug() << "Found originating Post; setting comments on it...";
             post->setComments(commentsList);
@@ -1456,7 +1458,7 @@ void TimeLine::goToSpecificPage(int pageNumber)
      * ALL posts, even beyond API limits, instead of the last (oldest) few
      * posts.
      *
-     * https://github.com/e14n/pump.io/issues/1087
+     * https://github.com/pump-io/pump.io/issues/1087
      *
      */
     if (this->timelineType == PumpController::UserTimelineRequest)
